@@ -204,7 +204,7 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
         """
         ### quering ###
         fk_id_function = management._query_func_id("get_critical_value")
-        messages = management._get_messages(fk_id_function, self.language)
+        messages = management._get_messages(fk_id_function, self.language, "get_critical_value")
 
         am_table = AbdiMolin.ABDIMOLIN_TABLE
 
@@ -267,14 +267,15 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
         return result(critical, alfa)
 
     # with tet, tieh text, with database, with docstring
-    def draw_critical_values(self, ax=None, export=None, extension=None, file_name=None, dpi=None, decimal_separator=None, local=None):
+    def draw_critical_values(self, ax=None, export=None, extension=None, file_name=None, dpi=None, decimal_separator=None):
         """Draw a plot with the AbdiMolin  [1]_ *critical data*.
 
         Parameters
         ----------
         ax : ``None`` or ``matplotlib.axes.SubplotBase``
-            If ``ax`` is ``None``, a figure is created with a preset design. The other parameters can be used to export the graph.
-            If ``ax`` is a ``matplotlib.axes.SubplotBase``, the function returns a ``matplotlib.axes.SubplotBase`` with the AbdiMolin critical data. In this case, the other parameters do not affect the graph.
+
+            * If ``ax`` is ``None``, a figure is created with a preset design. The other parameters can be used to export the graph.
+            * If ``ax`` is a ``matplotlib.axes.SubplotBase``, the function returns a ``matplotlib.axes.SubplotBase`` with the AbdiMolin critical data. In this case, the other parameters do not affect the graph.
         export : ``bool``, optional
             Whether the graph should be exported (``True``) or not (``False``). The default value is ``None``, which implies ``False``.
         file_name : ``str``, optional
@@ -285,8 +286,6 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
             The figure pixel density. The default is ``None``, which results in a ``100 dpis`` picture. This parameter must be a number higher than zero.
         decimal_separator : ``str``, optional
             The decimal separator symbol used in the chart. It can be the dot (``None`` or ``'.'``) or the comma (``','``).
-        local : ``str``, optional
-            The alias for the desired locale. Only used if ``decimal_separator=','`` to set the matplolib's default locale. Its only function is to change the decimal separator symbol and should be changed only if the ``"pt_BR"`` option is not available.
 
 
         Returns
@@ -362,18 +361,20 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
 
         ## decimal_separator ##
         decimal_separator = self._get_default_decimal_separator(decimal_separator)
+        checkers._check_is_str(decimal_separator, "decimal_separator", self.language)
+        helpers._check_decimal_separator(decimal_separator, self.language)
 
         ## local ##
-        local = self._get_default_local(local)
+        # local = self._get_default_local(local)
 
         fk_id_function = management._query_func_id("draw_critical_values")
-        messages = management._get_messages(fk_id_function, self.language)
+        messages = management._get_messages(fk_id_function, self.language, "draw_critical_values")
 
 
         ### The values tabled in a dictionary ###
         table = AbdiMolin.ABDIMOLIN_TABLE
 
-        default_locale = helpers._change_locale(self.language, decimal_separator, local)
+        # default_locale = helpers._change_locale(self.language, decimal_separator, local)
 
         ### Make the plot ###
         if ax is None:
@@ -392,18 +393,23 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
         axes.set_ylabel(messages[4][0][0])
         axes.set_xticks([4, 10, 15, 20, 25, 30, 35, 40, 45, 50])
 
+        # decimal separator
+        if ax is None:
+            axes = helpers._change_decimal_separator_x_axis(fig, axes, decimal_separator)
+            axes = helpers._change_decimal_separator_y_axis(fig, axes, decimal_separator)
 
         ## If show equals True, display the graph ##
         if ax is None:
             fig.tight_layout()
             if export:
                 ### Baptism of Fire ###
-                file_name = helpers._check_conflicting_filename(file_name, extension, self.language)
+                exits, file_name = helpers._check_conflicting_filename(file_name, extension, self.language)
                 plt.savefig(file_name, dpi=dpi, bbox_inches='tight')
                 general._display_one_line_success(f"{messages[5][0][0]} '{file_name}' {messages[5][2][0]}")
             plt.show()
 
-        helpers._change_locale_back_to_default(default_locale)
+        # helpers._change_locale_back_to_default(default_locale)
+
 
         return axes
 
@@ -711,12 +717,12 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
         """
         if self.msg is None:
             fk_id_function = management._query_func_id("AbdiMolin")
-            messages = management._get_messages(fk_id_function, self.language)
+            messages = management._get_messages(fk_id_function, self.language, "AbdiMolin")
             general._display_one_line_attention(messages[1][0][0])
         else:
             # quering
             fk_id_function = management._query_func_id("to_xlsx")
-            messages = management._get_messages(fk_id_function, self.language)
+            messages = management._get_messages(fk_id_function, self.language, "to_xlsx")
 
             # batizando o nome do arquivo
             if file_name is None:
@@ -844,7 +850,7 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
 
         if self.msg is None:
             fk_id_function = management._query_func_id("AbdiMolin")
-            messages = management._get_messages(fk_id_function, self.language)
+            messages = management._get_messages(fk_id_function, self.language, "AbdiMolin")
             general._display_one_line_attention(messages[1][0][0])
 
         else:
@@ -941,14 +947,14 @@ class AbdiMolin(AlphaManagement, NDigitsManagement, PlotsManagement):
     def __str__(self):
         if self.msg is None:
             fk_id_function = management._query_func_id("AbdiMolin")
-            messages = management._get_messages(fk_id_function, self.language)
+            messages = management._get_messages(fk_id_function, self.language, "AbdiMolin")
             return messages[1][0][0]
         else:
             return self.msg
 
     def __repr__(self):
         fk_id_function = management._query_func_id("AbdiMolin")
-        messages = management._get_messages(fk_id_function, self.language)
+        messages = management._get_messages(fk_id_function, self.language, "AbdiMolin")
         return messages[2][0][0]
 
 
