@@ -707,7 +707,7 @@ class StudentDistribution(PlotsManagement, AlphaManagement, NDigitsManagement):
             t_student = [stats.t.ppf(alfa, gl), stats.t.ppf(1 - alfa, gl)]
 
         fk_id_function = management._query_func_id("StudentDistribution")
-        messages = management._get_messages(fk_id_function, self.language)
+        messages = management._get_messages(fk_id_function, self.language, "StudentDistribution")
 
         result = namedtuple(messages[13][0][0], (messages[13][1][0], messages[13][2][0], messages[13][3][0], messages[13][4][0]))
 
@@ -926,7 +926,7 @@ class StudentDistribution(PlotsManagement, AlphaManagement, NDigitsManagement):
 
         """
         fk_id_function = management._query_func_id("StudentDistribution")
-        messages = management._get_messages(fk_id_function, self.language)
+        messages = management._get_messages(fk_id_function, self.language, "StudentDistribution")
 
         ### Checking the input parameters ###
 
@@ -1134,6 +1134,12 @@ class StudentDistribution(PlotsManagement, AlphaManagement, NDigitsManagement):
 
 
 
+    def compare_pairs(self, x_exp_1, x_exp_2, alfa=None, which=None, comparison=None, details=None):
+
+        pass
+
+
+
     def __str__(self):
         fk_id_function = management._query_func_id("StudentDistribution")
         messages = management._get_messages(fk_id_function, self.language)
