@@ -408,14 +408,18 @@ def _change_decimal_separator_x_axis(fig, axes, decimal_separator):
     """Esta função altera o separador de casa decimal através da mudança do seu label
     """
     if decimal_separator != ".":
-        new_x_ticks = []
+        new_x_ticks_labels = []
         fig.canvas.draw()
         for text in axes.get_xticklabels():
             result = _replace_last_occurrence(text.get_text(), '.', decimal_separator, 1)
-            new_x_ticks.append(result)
-        axes.set_xticklabels(new_x_ticks)
+            new_x_ticks_labels.append(result)
+        new_x_ticks = []
         for text in axes.get_xticklabels():
-            temp = text.get_text()
+            result = _replace_last_occurrence(text.get_text(), '.', decimal_separator, 1)
+            new_x_ticks.append(result)
+        axes.set_xticklabels(new_x_ticks_labels)
+        # for text in axes.get_xticklabels():
+        #     temp = text.get_text()
         return axes
     else:
         return axes
@@ -447,7 +451,7 @@ def _change_locale(language, decimal_separator=".", local="pt_BR"):
         The decimal separator symbol. It can be the dot (default '.') or the comma (',').
     local : string (default "pt_BR")
         The alias for the desired locale. Only used if decimal_separator is a comma, setting matplolib's default value. Its only function is to change the decimal separator symbol and should be changed only if the "pt_BR" option is not available.
-    language : string
+    language : ``str``
         The language code
 
     Notes
@@ -1396,7 +1400,7 @@ def _raises_when_fit_was_not_applied(func_name, language, name):
 
     """
     fk_id_function = management._query_func_id(func_name)
-    messages = management._get_messages(fk_id_function, language)
+    messages = management._get_messages(fk_id_function, language, func_name)
     try:
         error = messages[1][0][0]
         raise ValueError(error)
